@@ -1,6 +1,10 @@
 use strict;
 use warnings;
 package Email::MIME::Encode;
+{
+  $Email::MIME::Encode::VERSION = '1.921';
+}
+# ABSTRACT: a private helper for MIME header encoding
 
 use Email::Address;
 use Encode ();
@@ -117,3 +121,42 @@ sub mime_encode {
 }
 
 1;
+
+__END__
+
+=pod
+
+=head1 NAME
+
+Email::MIME::Encode - a private helper for MIME header encoding
+
+=head1 VERSION
+
+version 1.921
+
+=head1 AUTHORS
+
+=over 4
+
+=item *
+
+Ricardo SIGNES <rjbs@cpan.org>
+
+=item *
+
+Casey West <casey@geeknest.com>
+
+=item *
+
+Simon Cozens <simon@cpan.org>
+
+=back
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2004 by Simon Cozens and Casey West.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
+=cut
